@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef VIEWCONTAINER_H
@@ -47,6 +42,8 @@ namespace Konversation
 
 class ViewMimeData : public QMimeData
 {
+    Q_OBJECT
+
     public:
         explicit ViewMimeData(ChatWindow *view);
         ~ViewMimeData() override;
@@ -55,6 +52,8 @@ class ViewMimeData : public QMimeData
 
     private:
         ChatWindow *m_view;
+
+        Q_DISABLE_COPY(ViewMimeData)
 };
 
 class TabWidget : public QTabWidget
@@ -62,8 +61,8 @@ class TabWidget : public QTabWidget
     Q_OBJECT
 
     public:
-        explicit TabWidget(QWidget* parent = 0);
-        ~TabWidget() override;
+        explicit TabWidget(QWidget* parent = nullptr);
+        ~TabWidget();
 
     Q_SIGNALS:
         void contextMenu(QWidget* widget, const QPoint& pos);
@@ -72,6 +71,9 @@ class TabWidget : public QTabWidget
     protected:
         void contextMenuEvent(QContextMenuEvent* event) override;
         void mouseReleaseEvent(QMouseEvent* event) override;
+
+    private:
+        Q_DISABLE_COPY(TabWidget)
 };
 
 class ViewContainer : public QAbstractItemModel
@@ -88,12 +90,12 @@ class ViewContainer : public QAbstractItemModel
         explicit ViewContainer(MainWindow* window);
         ~ViewContainer() override;
 
-        QSplitter* getWidget() { return m_viewTreeSplitter; }
-        MainWindow* getWindow() { return m_window; }
-        KActionCollection* actionCollection() { return m_window->actionCollection(); }
+        QSplitter* getWidget() const { return m_viewTreeSplitter; }
+        MainWindow* getWindow() const { return m_window; }
+        KActionCollection* actionCollection() const { return m_window->actionCollection(); }
 
-        QPointer<ChatWindow> getFrontView() { return m_frontView; }
-        Server* getFrontServer() { return m_frontServer; }
+        QPointer<ChatWindow> getFrontView() const { return m_frontView; }
+        Server* getFrontServer() const { return m_frontServer; }
 
         void prepareShutdown();
 
@@ -116,7 +118,7 @@ class ViewContainer : public QAbstractItemModel
 
         bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
 
-        QString currentViewTitle();
+        QString currentViewTitle() const;
         QString currentViewURL(bool passNetwork = true);
 
         void appendToFrontmost(const QString& type,const QString& message,ChatWindow* serverView,
@@ -124,17 +126,17 @@ class ViewContainer : public QAbstractItemModel
 
         void showQueueTuner(bool);
 
-        int getViewIndex(QWidget* widget);
-        ChatWindow* getViewAt(int index);
+        int getViewIndex(QWidget* widget) const;
+        ChatWindow* getViewAt(int index) const;
 
-        QList<QPair<QString,QString> > getChannelsURI();
+        QList<QPair<QString,QString> > getChannelsURI() const;
 
     public Q_SLOTS:
         void updateAppearance();
         void saveSplitterSizes();
         void setViewTreeShown(bool show = false);
 
-        void updateViews(const Konversation::ServerGroupSettingsPtr serverGroup = Konversation::ServerGroupSettingsPtr());
+        void updateViews(const Konversation::ServerGroupSettingsPtr &serverGroup = Konversation::ServerGroupSettingsPtr());
         void setViewNotification(ChatWindow* widget, const Konversation::TabNotifyType& type);
         void unsetViewNotification(ChatWindow* view);
         void toggleViewNotifications();
@@ -201,7 +203,7 @@ class ViewContainer : public QAbstractItemModel
         void addDccPanel();
         void closeDccPanel();
         void deleteDccPanel();
-        ChatWindow* getDccPanel();
+        ChatWindow* getDccPanel() const;
 
         void addDccChat(Konversation::DCC::Chat* myNick);
 
@@ -223,7 +225,7 @@ class ViewContainer : public QAbstractItemModel
         void closeQueries();
 
         ChannelListPanel* addChannelListPanel(Server* server);
-        void openChannelList(Server* server = 0, const QString& filter = QString(), bool getList = false);
+        void openChannelList(Server* server = nullptr, const QString& filter = QString(), bool getList = false);
 
         void openNicksOnlinePanel();
         void closeNicksOnlinePanel();
@@ -270,6 +272,8 @@ class ViewContainer : public QAbstractItemModel
         void setFrontServer(Server *);
 
         void initializeSplitterSizes();
+
+    private:
         bool m_saveSplitterSizesLock;
 
         MainWindow* m_window;
@@ -304,6 +308,8 @@ class ViewContainer : public QAbstractItemModel
         QList<ChatWindow*> m_activeViewOrderList;
 
         ViewSpringLoader* m_viewSpringLoader;
+
+        Q_DISABLE_COPY(ViewContainer)
 };
 
 #endif
